package Bundle::Locale::CLDR::Westernasia;

use version;

our $VERSION = version->declare('v0.46.0');

=head1 NAME

Bundle::Locale::CLDR::Westernasia

=head1 CONTENTS

Locale::CLDR::Locales::Ab 0.46.0

Locale::CLDR::Locales::Ar 0.46.0

Locale::CLDR::Locales::Az 0.46.0

Locale::CLDR::Locales::El 0.46.0

Locale::CLDR::Locales::Fr 0.46.0

Locale::CLDR::Locales::He 0.46.0

Locale::CLDR::Locales::Hy 0.46.0

Locale::CLDR::Locales::Ka 0.46.0

Locale::CLDR::Locales::Ku 0.46.0

Locale::CLDR::Locales::Os 0.46.0

Locale::CLDR::Locales::Tr 0.46.0

Locale::CLDR::Locales::Apc 0.46.0

Locale::CLDR::Locales::Bgn 0.46.0

Locale::CLDR::Locales::Ckb 0.46.0

Locale::CLDR::Locales::Lrc 0.46.0

Locale::CLDR::Locales::Sdh 0.46.0

Locale::CLDR::Locales::Syr 0.46.0

Locale::CLDR::Locales::Ab::Cyrl 0.46.0

Locale::CLDR::Locales::Ar::Arab 0.46.0

Locale::CLDR::Locales::Az::Arab 0.46.0

Locale::CLDR::Locales::Az::Cyrl 0.46.0

Locale::CLDR::Locales::Az::Latn 0.46.0

Locale::CLDR::Locales::El::Grek 0.46.0

Locale::CLDR::Locales::Fr::Latn 0.46.0

Locale::CLDR::Locales::He::Hebr 0.46.0

Locale::CLDR::Locales::Hy::Armn 0.46.0

Locale::CLDR::Locales::Ka::Geor 0.46.0

Locale::CLDR::Locales::Ku::Latn 0.46.0

Locale::CLDR::Locales::Os::Cyrl 0.46.0

Locale::CLDR::Locales::Tr::Latn 0.46.0

Locale::CLDR::Locales::Apc::Arab 0.46.0

Locale::CLDR::Locales::Bgn::Arab 0.46.0

Locale::CLDR::Locales::Ckb::Arab 0.46.0

Locale::CLDR::Locales::Lrc::Arab 0.46.0

Locale::CLDR::Locales::Sdh::Arab 0.46.0

Locale::CLDR::Locales::Syr::Syrc 0.46.0

Locale::CLDR::Locales::Ab::Cyrl::Ge 0.46.0

Locale::CLDR::Locales::Ar::Arab::Ae 0.46.0

Locale::CLDR::Locales::Ar::Arab::Bh 0.46.0

Locale::CLDR::Locales::Ar::Arab::Il 0.46.0

Locale::CLDR::Locales::Ar::Arab::Iq 0.46.0

Locale::CLDR::Locales::Ar::Arab::Jo 0.46.0

Locale::CLDR::Locales::Ar::Arab::Kw 0.46.0

Locale::CLDR::Locales::Ar::Arab::Lb 0.46.0

Locale::CLDR::Locales::Ar::Arab::Om 0.46.0

Locale::CLDR::Locales::Ar::Arab::Ps 0.46.0

Locale::CLDR::Locales::Ar::Arab::Qa 0.46.0

Locale::CLDR::Locales::Ar::Arab::Sa 0.46.0

Locale::CLDR::Locales::Ar::Arab::Sy 0.46.0

Locale::CLDR::Locales::Ar::Arab::Ye 0.46.0

Locale::CLDR::Locales::Az::Arab::Iq 0.46.0

Locale::CLDR::Locales::Az::Arab::Tr 0.46.0

Locale::CLDR::Locales::Az::Cyrl::Az 0.46.0

Locale::CLDR::Locales::Az::Latn::Az 0.46.0

Locale::CLDR::Locales::El::Grek::Cy 0.46.0

Locale::CLDR::Locales::En::Latn::Ae 0.46.0

Locale::CLDR::Locales::En::Latn::Cy 0.46.0

Locale::CLDR::Locales::En::Latn::Il 0.46.0

Locale::CLDR::Locales::Fr::Latn::Sy 0.46.0

Locale::CLDR::Locales::He::Hebr::Il 0.46.0

Locale::CLDR::Locales::Hy::Armn::Am 0.46.0

Locale::CLDR::Locales::Ka::Geor::Ge 0.46.0

Locale::CLDR::Locales::Ku::Latn::Tr 0.46.0

Locale::CLDR::Locales::Os::Cyrl::Ge 0.46.0

Locale::CLDR::Locales::Tr::Latn::Cy 0.46.0

Locale::CLDR::Locales::Tr::Latn::Tr 0.46.0

Locale::CLDR::Locales::Apc::Arab::Sy 0.46.0

Locale::CLDR::Locales::Bgn::Arab::Ae 0.46.0

Locale::CLDR::Locales::Bgn::Arab::Om 0.46.0

Locale::CLDR::Locales::Ckb::Arab::Iq 0.46.0

Locale::CLDR::Locales::En::Latn::001 0.46.0

Locale::CLDR::Locales::Lrc::Arab::Iq 0.46.0

Locale::CLDR::Locales::Sdh::Arab::Iq 0.46.0

Locale::CLDR::Locales::Syr::Syrc::Iq 0.46.0

Locale::CLDR::Locales::Syr::Syrc::Sy 0.46.0


=cut

1;

